@@ -21,5 +21,5 @@
 pub mod base;
 pub mod identity;
 
-pub use self::base::{AuthMethod, NoAuth};
+pub use self::base::{AuthMethod, AuthToken, NoAuth};
 pub use self::identity::Identity;
